==> adeptarch_base-9.0.1%2B1.tar.gz: lib/src/widgets/enum_filter_view.dart <==
import 'package:adeptarch_base/src/widgets/widgets.dart';
import 'package:adeptarch_base/src/filters/filters.dart';
import 'package:flutter/material.dart';

// ignore_for_file: must_be_immutable
class EnumFilterView extends BaseFilterView<EnumFilter> {
  bool useTextUnspecified;
  String textUnspecified;
  List<String?>? entries;
  List<String?>? entryValues;

  EnumFilterView({
    FilterController<EnumFilter>? filterController,
    String? hint,
    bool? allowSorting,
    this.useTextUnspecified = true,
    this.textUnspecified = "Unspecified",
    this.entries,
    this.entryValues,
  }) : super(
          filterController: filterController,
          hint: hint,
          allowSorting: allowSorting,
        ) {
    assert(entries != null);
    assert(entryValues != null);
    assert(entries!.length == entryValues!.length);
    if (useTextUnspecified) {
      entries?.insert(0, textUnspecified);
      entryValues?.insert(0, 'null');
    }
  }

  @override
  State createState() => _EnumFilterViewState();
}

class _EnumFilterViewState extends State<EnumFilterView> {
  late Color colorPrimary, colorTextTertiary;
  List<DropdownMenuItem<String>>? enumFilterValues;

  @override
  void initState() {
    super.initState();
    init();
    listeners();
  }

  void init() {
    generateFilterItems();
    onFilterChanged();
  }

  void generateFilterItems() {
    enumFilterValues = [];
    for (int i = 0; i < widget.entries!.length; ++i) {
      enumFilterValues!.add(DropdownMenuItem(
        value: widget.entryValues![i],
        child: Text(widget.entries![i]!),
      ));
    }
  }

  void listeners() {
    widget.filterController.addListener(onFilterChanged);
  }

  void onFilterChanged() {
    EnumFilter? filter = widget.filterController.value;
    if (filter != null) {}
  }

  void checkColors(context) {
    colorPrimary = Theme.of(context).primaryColor;
    colorTextTertiary = Colors.grey.shade600;
  }

  @override
  Widget build(BuildContext context) {
    checkColors(context);
    return Row(
      children: [
        Expanded(
            child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: <Widget>[
            if (widget.hint != null)
              Text(
                widget.hint!,
                style: TextStyle(
                    color: widget.filterController.value?.value != null
                        ? colorPrimary
                        : colorTextTertiary,
                    fontSize: 12),
              ),
            Theme(
              data: ThemeData(brightness: Theme.of(context).brightness),
              child: DropdownButton<String>(
                isExpanded: true,
                items: enumFilterValues,
                value:
                    widget.filterController.value?.value?.toString() ?? 'null',
                onChanged: (value) {
                  if (value == null || value == 'null') {
                    widget.filterController.reset();
                  } else {
                    widget.filterController.value?.equals(value);
                    widget.filterController.clearError();
                  }
                  setState(() {});
                },
              ),
            ),
          ],
        )),
        Visibility(
          visible: widget.allowSorting,
          child: Container(
            margin: const EdgeInsets.only(top: 16),
            alignment: Alignment.bottomCenter,
            child: SortView(
              sortMode: widget.filterController.value?.sortMode,
              listener: (oldMode, newMode) {
                widget.filterController.value?.sortMode = newMode;
              },
            ),
          ),
        )
      ],
    );
  }

  @override
  void dispose() {
    widget.filterController.removeListener(onFilterChanged);
    super.dispose();
  }
}

==> adeptarch_base-12.0.0%2B1.tar.gz: lib/src/widgets/enum_filter_view.dart <==
import 'package:adeptarch_base/src/widgets/widgets.dart';
import 'package:adeptarch_base/src/filters/filters.dart';
import 'package:flutter/material.dart';

// ignore_for_file: must_be_immutable
class EnumFilterView extends BaseFilterView<EnumFilter> {
  bool useTextUnspecified;
  String textUnspecified;
  List<String?>? entries;
  List<String?>? entryValues;

  EnumFilterView({
    super.filterController,
    super.hint,
    super.allowSorting,
    this.useTextUnspecified = true,
    this.textUnspecified = "Unspecified",
    this.entries,
    this.entryValues,
  }) {
    assert(entries != null);
    assert(entryValues != null);
    assert(entries!.length == entryValues!.length);
    if (useTextUnspecified) {
      entries?.insert(0, textUnspecified);
      entryValues?.insert(0, 'null');
    }
  }

  @override
  State createState() => _EnumFilterViewState();
}

class _EnumFilterViewState extends State<EnumFilterView> {
  late Color colorPrimary, colorTextTertiary;
  List<DropdownMenuItem<String>>? enumFilterValues;

  @override
  void initState() {
    super.initState();
    init();
    listeners();
  }

  void init() {
    generateFilterItems();
    onFilterChanged();
  }

  void generateFilterItems() {
    enumFilterValues = [];
    for (int i = 0; i < widget.entries!.length; ++i) {
      enumFilterValues!.add(DropdownMenuItem(
        value: widget.entryValues![i],
        child: Text(widget.entries![i]!),
      ));
    }
  }

  void listeners() {
    widget.filterController.addListener(onFilterChanged);
  }

  void onFilterChanged() {
    EnumFilter? filter = widget.filterController.value;
    if (filter != null) {}
  }

  void checkColors(context) {
    colorPrimary = Theme.of(context).primaryColor;
    colorTextTertiary = Colors.grey.shade600;
  }

  @override
  Widget build(BuildContext context) {
    checkColors(context);
    return Row(
      children: [
        Expanded(
            child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: <Widget>[
            if (widget.hint != null)
              Text(
                widget.hint!,
                style: TextStyle(
                    color: widget.filterController.value?.value != null
                        ? colorPrimary
                        : colorTextTertiary,
                    fontSize: 12),
              ),
            Theme(
              data: ThemeData(brightness: Theme.of(context).brightness),
              child: DropdownButton<String>(
                isExpanded: true,
                items: enumFilterValues,
                value:
                    widget.filterController.value?.value?.toString() ?? 'null',
                onChanged: (value) {
                  if (value == null || value == 'null') {
                    widget.filterController.reset();
                  } else {
                    widget.filterController.value?.equals(value);
                    widget.filterController.clearError();
                  }
                  setState(() {});
                },
              ),
            ),
          ],
        )),
        Visibility(
          visible: widget.allowSorting,
          child: Container(
            margin: const EdgeInsets.only(top: 16),
            alignment: Alignment.bottomCenter,
            child: SortView(
              sortMode: widget.filterController.value?.sortMode,
              listener: (oldMode, newMode) {
                widget.filterController.value?.sortMode = newMode;
              },
            ),
          ),
        )
      ],
    );
  }

  @override
  void dispose() {
    widget.filterController.removeListener(onFilterChanged);
    super.dispose();
  }
}
